Struct sn_logging::ReloadHandle
source · pub struct ReloadHandle(/* private fields */);Expand description
Handle that implements functions to change the log level on the fly.
Implementations
sourceimpl ReloadHandle
impl ReloadHandle
sourcepub fn modify_log_level(&self, logging_value: &str) -> Result<(), Error>
pub fn modify_log_level(&self, logging_value: &str) -> Result<(), Error>
Modify the log level to the provided CSV value
Example input: libp2p=DEBUG, tokio=INFO, all, sn_client=ERROR
If any custom keyword is encountered in the CSV, for e.g., VERBOSE_SN_LOGS (‘all’), then they will override some
of the value that you might have provided, sn_client=ERROR in the above example will be ignored and
instead will be set to TRACE since all keyword is provided.